==> jmanager-1.0.3.tar.gz: jmanager-1.0.3/setup.py <==
#!/usr/bin/env python

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = ['Click>=7.0', 'jupyter']

setup_requirements = []

test_requirements = []

setup(
    author="Yasunori Horikoshi",
    author_email='horikoshi.et.al@gmail.com',
    python_requires='>=3.5',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    description="managing jupyter process with local pid file",
    entry_points={
        'console_scripts': [
            'jmanager=jmanager.cli:main',
        ],
    },
    install_requires=requirements,
    license="MIT license",
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords='jmanager',
    name='jmanager',
    packages=find_packages(include=['jmanager', 'jmanager.*']),
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/hotoku/jmanager',
    version='1.0.3',
    zip_safe=False,
)

==> jmanager-1.0.4.tar.gz: jmanager-1.0.4/setup.py <==
#!/usr/bin/env python

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = ['Click>=7.0', 'jupyterlab']

setup_requirements = []

test_requirements = []

setup(
    author="Yasunori Horikoshi",
    author_email='horikoshi.et.al@gmail.com',
    python_requires='>=3.5',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    description="managing jupyter process with local pid file",
    entry_points={
        'console_scripts': [
            'jmanager=jmanager.cli:main',
        ],
    },
    install_requires=requirements,
    license="MIT license",
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords='jmanager',
    name='jmanager',
    packages=find_packages(include=['jmanager', 'jmanager.*']),
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/hotoku/jmanager',
    version='1.0.4',
    zip_safe=False,
)
